/*
 * [DefaultApps.java]
 *
 * Summary: Default settings for a group of common apps.
 *
 * Copyright: (c) 2009-2017 Roedy Green, Canadian Mind Products, http://mindprod.com
 *
 * Licence: This software may be copied and used freely for any purpose but military.
 *          http://mindprod.com/contact/nonmil.html
 *
 * Requires: JDK 1.8+
 *
 * Created with: JetBrains IntelliJ IDEA IDE http://www.jetbrains.com/idea/
 *
 * Version History:
 *  3.8 2009-03-31 change order of fields in defaults.csv.
 */
package com.mindprod.vercheck;

import com.mindprod.common18.EIO;

import java.io.IOException;
import java.io.ObjectInputStream;

import static java.lang.System.*;

/**
 * Default settings for a group of common apps.
 *
 * @author Roedy Green, Canadian Mind Products
 * @version 3.8 2009-03-31 change order of fields in defaults.csv.
 * @since 2009
 */
class DefaultApps
    {
    /**
     * information about all default apps
     */
    static AppToWatch[] defaults;

    /**
     * apps deleted
     */
    static String[] obsoletes;

    static
        {
        try
            {
            // O P E N
            ObjectInputStream ois = EIO.getObjectInputStream( DefaultApps.class.getResourceAsStream( "defaults.ser" ), 4 * 1024, true );
            // R E A D
            defaults = ( AppToWatch[] ) ois.readObject();
            // C L O S E
            ois.close();
            }
        catch ( ClassNotFoundException e )
            {
            err.println( "Needed class missing from jar" );
            System.exit( 1 );
            }
        catch ( IOException e )
            {
            err.println( "Failed to load list of default apps resource from the jar." );
            defaults = new AppToWatch[ 0 ];
            }
        }

    static
        {
        try
            {
            // O P E N
            ObjectInputStream ois = EIO.getObjectInputStream( DefaultApps.class.getResourceAsStream( "obsoletes.ser" ), 4 * 1024, true );
            // R E A D
            obsoletes = ( String[] ) ois.readObject();
            // C L O S E
            ois.close();
            }
        catch ( ClassNotFoundException e )
            {
            err.println( "Needed class missing from jar" );
            System.exit( 1 );
            }
        catch ( IOException e )
            {
            err.println( "Failed to load list of obsolete apps resource from the jar." );
            obsoletes = new String[ 0 ];
            }
        }
    }
