/*
 * [Staged.java]
 *
 * Summary: Check when a series of markers must matech.
 *
 * Copyright: (c) 2016-2017 Roedy Green, Canadian Mind Products, http://mindprod.com
 *
 * Licence: This software may be copied and used freely for any purpose but military.
 *          http://mindprod.com/contact/nonmil.html
 *
 * Requires: JDK 1.8+
 *
 * Created with: JetBrains IntelliJ IDEA IDE http://www.jetbrains.com/idea/
 *
 * Version History:
 *  1.0 2016-06-24 initial release
 */
package com.mindprod.vercheck;

import java.util.regex.Pattern;

/**
 * Check when a series of markers must matech.
 *
 * @author Roedy Green, Canadian Mind Products
 * @version 1.0 2016-06-24 initial release
 * @since 2016-06-24
 */
class Staged
    {
    private static final Pattern SPLIT_ON_OR = Pattern.compile( "\\|" );

    /**
     * turn true if markers found that indicate products has not changed.
     *
     * @param big the entire web page
     *
     * @return true if unchanged (markers found)
     * @parm marker string of markers, separatade by | without lead staged:
     */
    static boolean found( final String big, final String marker )
        {
        final String[] legs = SPLIT_ON_OR.split( marker );
        int start = 0;
        for ( String leg : legs )
            {
            int startLeg = big.indexOf( leg, start );
            if ( startLeg < 0 )
                {
                return false;
                }
            start = startLeg + leg.length();
            }
        return true;
        }
    }
